@@ -3,10 +3,10 @@
 
 # Configuration variables
 
-sdk_version = "0.16.1"
+sdk_version = "0.16.5"
 
 api_key = None
-client_id = None
+assume_org_id = None
 api_base = "https://v1.api.audio"
 upload_api_base = "https://file.api.audio"  # not implemented yet.
 
@@ -21,10 +21,12 @@ max_network_retries = 0
 
 # API resources
 from apiaudio.api_resources import *
+from apiaudio.api_request import APIRequest
 
 # logging
 from apiaudio.logging import SDKLogger
 
+
 _logger = SDKLogger()
 _version_warning_issued = False
 
@@ -35,3 +37,8 @@ def set_logger_level(level):
     assert level in available_levels, f"Available logging levels: {available_levels}"
 
     _logger = SDKLogger(level=level)
+
+
+# super org assume mechanism
+def set_assume_org_id(org_id):
+    return APIRequest.set_assume_org_id(org_id)
