@@ -30,16 +30,24 @@ class APIRequest:
         apiaudio.api_key = api_key
         return
 
+    def set_assume_org_id(org_id):
+        apiaudio.assume_org_id = org_id
+
     @classmethod
     def _build_header(cls):
         cls._api_key_checker(apiaudio.api_key)
-        return {"x-api-key": apiaudio.api_key, "x-python-sdk-version": sdk_version}
+        return {
+            "x-api-key": apiaudio.api_key,
+            "x-python-sdk-version": sdk_version,
+            "x-assume-org": apiaudio.assume_org_id,
+        }
 
     @classmethod
-    def _post_request(cls, json, url=None):
+    def _post_request(cls, json, url=None, headers=None):
+        headers = headers or {}
         loop_status_code = cls.__dict__.get("loop_status_code")
         url = url or f"{apiaudio.api_base}{cls.resource_path}"
-        headers = cls._build_header()
+        headers.update(cls._build_header())
         r = requests.post(url=url, headers=headers, json=json)
 
         if loop_status_code:
@@ -51,21 +59,10 @@ class APIRequest:
 
         cls._expanded_raise_for_status(r)
 
+        if r.headers["Content-Type"] != "application/json":
+            return r.content
         return r.json()
 
-    @classmethod
-    def _post_request_raw(cls, json, url=None, istype="wav"):
-        url = url or cls.resource_path
-        url = f"{apiaudio.api_base}{url}"
-        headers = cls._build_header()
-        if istype == "wav":
-            headers["Accept"] = "audio/wav"
-        r = requests.post(url=url, headers=headers, json=json)
-
-        cls._expanded_raise_for_status(r)
-
-        return r.content
-
     @classmethod
     def _delete_request(cls, url=None, path_param=None, request_params=None):
         url = url or f"{apiaudio.api_base}{cls.resource_path}"
